#
# spec file for package retroarch
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           retroarch
Version:        1.8.6
Release:        bp153.1.25
Summary:        Emulator frontend
License:        GPL-3.0-only
Group:          System/Emulators/Other
URL:            http://www.retroarch.com
Source:         %{name}-%{version}.tar.gz
Patch0:         retroarch-config.patch

BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  p7zip
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  unzip
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(SDL2_gfx)
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(SDL2_ttf)
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(gbm)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(jack)
BuildRequires:  pkgconfig(libass)
BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(libudev)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(libv4l2)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl2)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xinerama)
BuildRequires:  pkgconfig(xkbcommon)
BuildRequires:  pkgconfig(xv)
BuildRequires:  pkgconfig(xxf86vm)
BuildRequires:  pkgconfig(zlib)
%if ( 0%{?suse_version} || 0%{?leap_version} )
BuildRequires:  update-desktop-files
BuildRequires:  vulkan-devel
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavdevice)
BuildRequires:  pkgconfig(libavformat)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libswscale)
%endif

# Shared data
Recommends:     retroarch-joypad-autoconfig
Recommends:     retroarch-assets
Recommends:     libretro-core-info
Recommends:     libretro-database

# Emulation cores

# Arcade/MAME for old roms
Recommends:     libretro-mame2003-plus
# Arcade/MAME for latest roms
Recommends:     libretro-mame

# Atari 2600
Recommends:     libretro-stella
# Atari 5200
Recommends:     libretro-atari800
# Atari 7800
Recommends:     libretro-prosystem
# Atari Jaguar
Recommends:     libretro-virtualjaguar
# Atari Lynx
Recommends:     libretro-handy

# Nintendo Entertainment System (NES)
Recommends:     libretro-nestopia
# Super Nintendo Entertainment System (SNES)
Recommends:     libretro-bsnes
# Nintendo 64 (N64)
Recommends:     libretro-parallel-n64
# GameCube (GC) and Wii (not fully working yet)
Recommends:     libretro-dolphin

# Nintendo Game Boy Color (GBC)
Recommends:     libretro-gambatte
# Nintendo Game Boy Advance (GBA)
Recommends:     libretro-mgba
# Nintendo DS (NDS)
Recommends:     libretro-desmume
# Nintendo 3DS (3DS)
Recommends:     libretro-citra

# Sega Genesis/Mega Drive (MD)
Recommends:     libretro-blastem
# Sega Saturn (SS)
Recommends:     libretro-yabause
# Sega Dreamcast (DC)
Recommends:     libretro-flycast

# Sony PlayStation (PSX)
Recommends:     libretro-pcsx-rearmed
# Sony PlayStation 2 (PS2)
Recommends:     libretro-play
# Sony PlayStation Portable (PSP)
Recommends:     libretro-ppsspp

# Amstrad
Recommends:     libretro-crocods
# Amstrad CPC
Recommends:     libretro-cap32
# Bandai WonderSwan
Recommends:     libretro-beetle-wswan
# Fairchild ChannelF
Recommends:     libretro-freechaf
# Mattel Intellivision
Recommends:     libretro-freeintv
# MS DOS
Recommends:     libretro-dosbox
# MSX
Recommends:     libretro-bluemsx
# Neo Geo Pocket
Recommends:     libretro-beetle-ngp
# PC Engine/TurboGrafx-16
Recommends:     libretro-beetle-pce-fast
# ZX 81
Recommends:     libretro-81
# ZX Spectrum
Recommends:     libretro-fuse

# Game and game engine cores

Recommends:     libretro-2048
Recommends:     libretro-3dengine
Recommends:     libretro-chailove
Recommends:     libretro-craft
Recommends:     libretro-easyrpg
Recommends:     libretro-ffmpeg

%description
RetroArch is a modular multi-system emulator system that is designed to be
fast, lightweight, and portable. It has features few other emulators frontends
have, such as real-time rewinding and game-aware shading.

%prep
%setup -q

%autopatch -p1

# Change /usr/lib/ to /usr/lib64/ on 64-bit platform
sed -i s~/usr/lib/~%{_libdir}/~g retroarch.cfg

%build
export CFLAGS="%{optflags}"
export CXXFLAGS="$CFLAGS"
./configure --prefix=%{_prefix} \
    --enable-materialui \
    --enable-xmb \
    --enable-sdl2 \
    --enable-libusb \
    --enable-udev \
    --enable-threads \
    --enable-thread_storage \
    --enable-ffmpeg \
    --enable-ssa \
    --enable-dylib \
    --enable-networking \
    --enable-networkgamepad \
    --enable-opengl \
    --enable-x11 \
    --enable-xinerama\
    --enable-kms \
    --enable-wayland \
    --enable-egl \
    --enable-zlib \
    --enable-alsa \
    --enable-al \
    --enable-jack \
    --enable-pulse \
    --enable-freetype \
    --enable-xvideo \
    --enable-v4l2 \
    --enable-qt \
    --enable-dbus \
%ifarch x86
    --enable-sse \
%endif
%if ( 0%{?suse_version} || 0%{?leap_version} )
    --enable-vulkan \
%endif
    --enable-7zip \
    --enable-mmap
make %{?_smp_mflags}

%install
%make_install

%fdupes %{buildroot}

%files
%config(noreplace) %{_sysconfdir}/%{name}.cfg
%{_bindir}/%{name}
%{_bindir}/%{name}-cg2glsl
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.svg
%{_mandir}/man?/%{name}.?*
%{_mandir}/man?/%{name}-cg2glsl.?*
%{_datadir}/doc/%{name}

%changelog
* Thu May  7 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.6
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#186
* Wed Mar 25 2020 Karol Sławiński <karol_slawinski@wp.pl>
- Version 1.8.5
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#185
* Wed Feb 19 2020 Yunhe Guo <i@guoyunhe.me>
- Add more core recommends
* Mon Feb  3 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  allow OBS to shortcut through -mini flavors.
* Wed Jan 22 2020 Yunhe Guo <i@guoyunhe.me>
- Exclude unneeded lib directory with license issues
* Wed Jan 15 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.4
  * Full changelog at https://github.com/libretro/RetroArch/blob/master/CHANGES.md#184
* Fri Jan 10 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.3
* Wed Jan  1 2020 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.2
- Recommend more available cores
- Remove --with-man_dir parameter to fix build
* Wed Nov  6 2019 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.1
- Added pkgconfig(xxf86vm) build dependency
- Update retroarch-config.patch:
  * Enable online updater, so users can download some game content
* Sat Oct 26 2019 Yunhe Guo <i@guoyunhe.me>
- Version 1.8.0
* Thu Oct 24 2019 Yunhe Guo <i@guoyunhe.me>
- Enable DBus to solve screen off issue during game play
* Thu Oct  3 2019 Yunhe Guo <i@guoyunhe.me>
- Add recommends for Atari, MAME, Nintendo, Sega, Sony emulator cores
* Mon Sep 30 2019 Yunhe Guo <i@guoyunhe.me>
- Update retroarch-config.patch
  * Revert system_directory to default. It must be a writable location
    for some cores. Otherwise, games cannot be loaded.
* Tue Sep 24 2019 Yunhe Guo <i@guoyunhe.me>
- Update retroarch-config.patch
  * Disable menu_show_online_updater because thumbnails will be
    downloaded on demand and all other content should be provided
    by RPM packages
  * Set rgui_browser_directory to user home instead of system root
  * Enable network_on_demand_thumbnails option
  * Set system_directory so we can package some core system files
* Sun Sep 22 2019 Yunhe Guo <i@guoyunhe.me>
- Recommends:
  * libretro-core-info
  * libretro-database
  * libretro-nestopia
  * libretro-bsnes
  * libretro-mgba
  * libretro-gambatte
* Sun Sep 22 2019 Yunhe Guo <i@guoyunhe.me>
- Add retroarch-config.patch to disable in-app updates and enable
  system assets directory
- Remove retroarch.desktop because it is already in source tarball
* Fri Sep 20 2019 Yunhe Guo <i@guoyunhe.me>
- Update to 1.7.8.4
  * Update AndroidManifest.xml
- Update to 1.7.8.3
  * Update CHANGES.md
- Update to 1.7.8.2
  * Update CHANGES.md
- Recommend retroarch-joypad-autoconfig and retroarch-assets
* Mon Sep  2 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add pkgconfig(Qt5Concurrent) to BuildRequires
- Add pkgconfig(Qt5Network) to BuildRequires
- Drop %%{_datadir}/retroarch directory from %%files section
- Drop deprecated --enable-python parameter from configure line
* Wed Aug 28 2019 Marcus Meissner <meissner@suse.com>
- updated to 1.7.8
  - 3DS: Fix C-Stick y-axis inversion
  - 3DS: Update all icon/banner images
  - AI: Add AI Service functionality (enabled for Windows/Mac/Linux/Android/iOS).
  - APPLE (MAC/IOS/TVOS): Fix autodetect for mFI controllers: properly call autodetect add on the connect notification, and add call to disconnect on GameController disconnect notification.
  - ANDROID: Implemented multi-touch touchscreen support
  - ANDROID: Now can be built with Gradle/Android Studio
  - AUDIO/WINDOWS: You can now select between audio devices for XAudio2/DirectSound/XAudio2 by pressing left/right on the Audio Device option.
  - AUDIO/WINDOWS: Setting the device by either index number or name string should work.
  - BLISS-BOX: Add 4 new pad types from firmware 3.0
  - BPS/UPS: Re-allocation target_data variable for target patch size (can now apply bigger patches without extra-bytes on memory)
  - CDROM: Added real CD-ROM functionality for Windows and Linux.
  - CDROM: Added disc dumping.
  - COMMON: Add separate frontend logging
  - COMMON: Ability to set FPS update interval (used in the window titlebar/FPS widget)
  - COMMON: Add 'Reset Frame Time Counter' functionality, enable it by default for resizing the window, loading/saving shader presets, fastforwarding, etc.
  - COMMON: Add optional 'on demand' thumbnail downloads
  - COMMON: Add new playlist-based thumbnail downloader. Hide the legacy thumbnail pack version by default
  - COMMON: Show license per core (if available) inside 'Load Core'
  - COMMON: Add option to load content from (and dump) CD-ROM discs
  - COMMON: Re-enable '--log-file' command line option
  - COMMON: Default playlist core association is now stored as metadata inside each playlist
  - COMMON: Fix playlist format detection
  - COMMON: Favorites playlist size can now be set independently of content history size. Values can be set from 0-999, or '-1' for unlimited (99999)
  - COMMON: Prevent adding new items to favorites when playlist is full (old entries are no longer overwritten)
  - COMMON: Prevent loading content with cores that require an incompatible graphics API version from the current one
  - COMMON: Saved shader presets are now portable across platforms and use relative paths
  - COMMON: Add '--set-shader' command line option which works like an override for automatic shader presets
  - COMMON: Add global shader presets
  - COMMON: Remove 'video_shader' setting, shaders are not saved automatically anymore
  - CORE OPTIONS: When saving core option overrides, only include settings for the current core
  - CORE OPTIONS: Add option to save core options per-core
  - CPU FILTERS: Add Scanline2x filter
  - DINPUT: Cleanup magic numbers mess surrounding hat code
  - GAMECUBE: Add default video/audio filter directories
  - GL/MALI400: Fix menu issues on Mali 400 series GPUs, should also fix 'RetroArch flickers black on ARM Mali GPUs (Android/ARM Linux)
  - GL/GLCORE: Use highest supported OpenGL Core version on Windows and X11
  - GL1: Ignore alpha in core video, fixes XRGB8888 rendering in some cores
  - GLCORE: Don't hardcode shader cross compilation target version but poll it. glcore would always only use the minimum target shader version, i.e. GLSL ES 3.00 for OpenGL ES 3.0+ or GLSL 1.50 for OpenGL 3.2+
  - D3D10/11/12/SLANG: Added "FrameDirection" slang semantic. Works fine with braid-rewind shader, not entirely perfect with D3D12 though
  - D3D10/11/12: Add option to select which GPU to render with
  - D3D10/11: Fix maintaining aspect ratio when resizing window
  - GLCORE/SLANG: Added "FrameDirection" slang semantic
  - HID: Add Retrode support. Should work on Wii/WiiU.
  - INPUT: Menu toggle hotkey can now be bound to another keyboard key and it will toggle properly
  - IOS: Correctly centers screen on iPhone X landscape
  - IOS: Implemented multi-touch touchscreen support
  - IOS: Add in more Apple Model numbers for RetroRating Added in all current Apple Model numbers and set a base rating of 19
  - IOS: Remove pause indicator; show the native UI menu using 4-finger swipe down gesture
  - IOS: Support L3/R3 in iOS 12.1, Options buttons in MFi/PS4/XBox One controllers in iOS 13
  - LIBRETRO: Add new core options interface, allows for localization, sublabels and more
  - LIBRETRO: Add new bitmask input codepath, for RETRO_DEVICE_ID_JOYPAD only for now
  - LOCALIZATION: Update Korean translation
  - LOCALIZATION: Update Japanese translation
  - LOCALIZATION: Update Portuguese Brazilian Translation
  - LOCALIZATION: Update Polish translation
  - LOCALIZATION: Update Turkish translation
  - MENU: Add smooth ticker text
  - MENU: Ability to hide every settings submenu (User Interface -> Views -> Settings)
  - MENU: Ability to hide nearly every quick menu entry (User Interface -> Views -> Quick Menu)
  - MENU: Fix longstanding menu display issues on Mali400 GPUs (on ARM hardware, SBCs and mobile phones/tablets)
  - MENU: Fix Record -> Streaming Quality, and Record -> Recording Threads settings
  - MENU: Fix history playlist navigation after running content
  - NENU: Menu entry performance optimisations
  - MENU: Add option to show 'remove playlist entry' only on history/favourites
  - MENU: Overhaul content 'Information' menu display
  - MENU: Add new 'Playlist Management' submenu. Allows default core associations to be set (via dropdown list), and all existing associations to be reset
  - MENU: Add 'Set Core Association' option to Quick Menu
  - MENU: Add option to remain in menu after saving/loading states
  - MENU: Pressing the Start button on 'Load Core' will unload the core.
  - MENU: After a core is running, Load Core will be hidden from view until you select 'Close Content' from the Quick Menu.
  - MENU/WIDGETS: All widgets are now properly cleaned up, fixing the frozen widgets bug when loading / closing content
  - MENU/WIDGETS: Fix crash with tasks
  - MENU/WIDGETS: Widgets are now drawn above the overlay with OpenGL and Vulkan
  - MENU/WIDGETS: Fine tune progress bar colors
  - MENU/WIDGETS: Have the progression widget always resize
  - MENU/THUMBNAILS: Ensure that displayed thumbnails are always refreshed correctly after selecting 'Download Thumbnails' from Quick Menu
  - MENU/THUMBNAILS: Make PNG image loading/processing non-blocking on non-threaded systems
  - MENU/OZONE: Add it for PS3
  - MENU/OZONE: Fix regression in 1.7.7 - OSX/macOS - was unable to start it
  - MENU/OZONE: Fix sublabel spacing
  - MENU/OZONE: Add toggle to enable/disable playlist name truncation in Ozone
  - MENU/OZONE: (Ozone) Fix display of (semi-)transparent thumbnails
  - MENU/XMB: Add menu animation settings
  - MENU/XMB: Add optional thumbnail scaling
  - MENU/XMB: Fix display of long sublabels. Text that would exceed the display area now scrolls line-by-line
  - MENU/XMB/OZONE: Add optional thumbnail upscaling
  - MENU/QT/WIMP: Add core option sublabels as tooltips, add buttons to reset one/all core options
  - MENU/QT/WIMP: Word-wrap core option tooltips
  - MENU/QT/WIMP: Path selector fixes
  - MENU/RGUI: Enable playlist display on platforms without database support
  - MENU/RGUI: Make particle effects framerate independent + add animation speed setting
  - MIDI: correct pitch bend in ALSA driver - MIDI standard pitch bend center position is 0x2000 but ALSA's is 0
  - MIDI: Fix SysEx handling. We need to clear the event status after each message. Otherwise, after a SysEx message the first byte of the next event will incorrectly inherit its delta_time. This causes a delay of several seconds in nearly every MT-32 games which uses a lot of long SysEx.
  - METAL/SLANG: Added "FrameDirection" slang semantic
  - NETBSD: Audioio is now the default audio driver
  - NETBSD: Fix a segfault when starting RetroArch with an empty configuration file and LANG unset in the environment
  - OSD: OSD is now drawn above the overlay with Vulkan
  - OSX: Fix regression with Cocoa GL - shader / preset loading was getting stuck in an infinite loop
  - OSX: Add improved menu resizing for window resizing
  - PLAYLISTS: Add history/favourites to 'Playlist Management' menu
  - RECORD: Fix Twitch streaming
  - REMOTE RETROPAD: Fix for Remote RetroPad input - fixes processing of Remote RetroPad input. None of the remote inputs are being executed both in menu and in game. This is due to the way current key binds are being detected which block processing of any remote input. It's been tested using Remote RetroPad core on Android including digital dpad and analog control input.
  - RUNAHEAD/MSVC2010:  Build in runahead support for MSVC2010 and up
  - RUNAHEAD/VITA: Build in runahead support for Vita version
  - SAVESTATES: Allow auto save states also in cores that support no content as long as some content is loaded
  - SCALER: Fix SSE2 path for ARGB/BGRA -> BGR24 - should fix screenshots being taken for XRGB888 (viewport)
  - SCANNER: Skip all databases with incompatible file extensions, whether content is inside an archive or not
  - SCANNER: Fix hang on empty files inside archives
  - SHADERS: Add proper shader compatibility checks
  - SHADERS: Enable Cg shaders for D3D9
  - SHADERS: Remove 'video_shader' setting, replace it with global presets that make more sense
  - SHADERS: #reference directive for shaders. Presets can point to other existing presets if they are unchanged
  - SHADERS: Will attempt to cache the shader/preset into memory before loading to avoid costly getline/gets/getc operations
  - SHADERS: New --set-shader commandline option
  - SHADERS/MENU: Prevent undefined behaviour when failing to load shaders
  - SHADERS/MENU: Pressing the Start button on 'Load Shader Preset' will reset all shader passes and apply changes, effectively disabling the shaders
  - SHADERS/MENU: New menu options for removing shader presets (global/core/parent/etc).
  - SWITCH :Add Audren audio driver.
  - SWITCH: Fix splitting and joining of joycon controllers. Before this fix, splitting and joining of joycons only ever worked sporadically
  - SWITCH: Proper x/y scaling for pointer devices, fixes touch lightgun
  - THUMBNAILS: Add optional On-Demand Thumbnails.
  - UDEV: Fix wrong udev devices order
  - UDEV/X11: Mouse pointer should work now in X11 environment with no Display
  - VITA: Update Vita2D
  - VULKAN/SLANG: Added "FrameDirection" slang semantic
  - VULKAN: Add option to select which GPU to render with
  - VULKAN: Validate non-causal filter chain for texture inputs. We only validated for UBO inputs apparently.
  - WINDOWS: Menubar should no longer be disabled when threaded video is enabled
  - WINDOWS: Add improved menu resizing for window resizing
  - WINDOWS: Properly set initial directory for menubar 'Load Core' option
  - WII: Add default video/audio filter directories
  - WII: Fix RGUI display corruption
  - WII: Fix HID joypad drivers
  - WII: Add optional overscan correction
  - WII: Fix recursive path_mkdir() operations
  - WII: Add widescreen RGUI support
  - WIIU: Scale menu to viewport size; respect filtering settings for menu
  - WIIU/RGUI: RGUI does its own transparency effects in the texture, so we don't have to add another 50%% on that
  - WIIU/RGUI: Use correct pixelformat ordering for menu texture
  - WIIU/SLANG: Added "FrameDirection" slang semantic
  - X11: Add improved menu resizing for window resizing
  - X11: Add non-evdev keycodes to fix keyboard input on non-Linux systems with X11
* Tue May 21 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- update to version 1.7.7
  * 3DS: Add unique IDs to prevent cores overwriting each other.
  * 3DS: Fix screen tearing when running 50Hz content.
  * ANDROID: We now target API level 26 (minimum is still API level 9).
  * ANDROID: Add option to vibrate on touch (works in menu or overlay).
  * ANDROID: Add device vibration option for cores that support rumble.
  * ANDROID: Add gamepad vibration support for cores that support rumble.
  * ANDROID: Allow stylus/pen to move mouse without pressing down.
  * AUDIO: Avoid deadlocks in certain audio drivers when toggling menu sounds on.
  * BLISS-BOX: Support PSX Jogcon (requires firmware 3.0).
  * CHEEVOS: Fix crash when reading memory that is out of range.
  * CHEEVOS: New Cheevos implementation enabled by default.
  * CHEEVOS: Pop-up badges when an achievement is triggered.
  * CRT: Dynamic super resolution support.
  * DISCORD: Fix potential crash when username is empty and discord is disabled.
  * DISCORD: Ask to join support for Linux.
  * INPUT/ANDROID: Add "Input Block Timeout" option.
  * COMMON: For platforms without HAVE_THREADS, don't automatically resume content when saving/loading states
  * COMMON: Make playlist sorting optional and consistent.
  * COMMON: Fix sorting of playlists with blank labels.
  * COMMON: Fix content scanner creating false positive playlist entries that also have wrong label and crc32.
  * COMMON: Add some MMX-optimized pixel conversion routines.
  * COMMON: Fix typo preventing some SSE2-optimized pixel conversions from being used.
  * COMMON: Add option to track how long content has been running over time.
  * COMMON: Fix buffer overflows in system information.
  * COMMON: Add option to change screen orientation via the windowing system (Android, Windows, X11).
  * COMMON: Show CPU model name in log.
  * COMMON: Add "Help -> Send Debug Info" option (and F10 hotkey) to send diagnostic info to the RetroArch team for help with problems.
  * COMMON: Show GPU device name/version in log.
  * COMMON: Add menu option to write log info to a file.
  * COMMON: Add subsystem support for playlists. Subsystem info is automatically saved to the history playlist for easy relaunching.
  * GL: Add new "gl1" OpenGL 1.1 compliant video driver for legacy GPUs and software renderers
  * GL: Add a new "glcore" driver with slang support (requires GL 3.2+ or GLES3).
  * GL: Draw OSD on top of overlay.
  * GONG: Add savestate support.
  * GONG: Add video refresh rate core options.
  * GONG: Two player support via core option.
  * GUI: Fix text alignment when using stb_unicode.
  * GUI: Fix text display issues when using Japanese (and other unicode-dependent language) text with stb_unicode.
  * GUI: Set language on first startup to the user's preferred OS language (Windows, *nix and Android).
  * INPUT: Add (scaled radial) analog deadzone and sensitivity options.
  * LIBRETRO: Add Turkish language support.
  * LIBRETRO: Allow non-accelerated video to rotate the display.
  * LOCALIZATION: Update Chinese (Simplified) translation.
  * LOCALIZATION: Update Chinese (Traditional) translation.
  * LOCALIZATION: Update Dutch translation.
  * LOCALIZATION: Update French translation.
  * LOCALIZATION: Update German translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Polish translation.
  * LOCALIZATION: Update Russian translation.
  * LOCALIZATION: Update Spanish translation.
  * LOCALIZATION: Add new Turkish translation.
  * MIDI: Fix startup crash in midi driver.
  * MENU: Bugfix - you can no longer get stuck in Online Updater
  - > Update Core screen when toggling between ingame and menu.
  * MENU: Selectively hide 'Take Screenshot' for video drivers
    that don't support taking screenshots.
  * MENU: Framerate independent menu rendering. MaterialUI/Ozone/
    XMB/RGUI can now run at higher framerates.
  * MENU: Thumbnails work in history list.
  * MENU: Menu widgets.
  * MENU: Add memory statistics support to more context drivers.
  * MENU: Enable ozone driver for UWP builds.
  * MENU: Add optional "looping" menu text ticker with configurable speed.
  * MENU: Fix core video rendering when using ozone with GL cores that
    implement the scissor test.
  * MENU: Add optional playlist sublabels (associated core + play
    time, where available).
  * MENU: Dropdown list settings now apply immediately.
  * MENU: Add setting to require pressing the "Exit RetroArch"
    hotkey twice to confirm.
  * MENU: Now able to run at higher refresh rates than 60Hz.
  * MENU: Enable "Add to Favorites" without loading a core.
  * MENU: Allow core name to be hidden on history/favorites playlists.
  * MENU: Populate crc32 and db_name fields when adding history/
    favourites playlist entries.
  * MENU: Fix TTF files not showing in OSD/menu font selection screen.
  * MENU: Fix audio/video filters not showing in file browser.
  * MENU/MaterialUI: Add subsystem support.
  * MENU/MaterialUI: Add currently selected entry in dropdown menus.
  * MENU/OZONE: Add mouse support on entries (no sidebar yet).
  * MENU/OZONE: Allow collapsing the sidebar.
  * MENU/OZONE: Add thumbnail support.
  * MENU/OZONE: Battery notifications.
  * MENU/OZONE: Add wifi icon for network entries.
  * MENU/QT/WIMP: Add git version and build date to Help->About window.
  * MENU/QT/WIMP: Fix content loading via the file browser.
  * MENU/QT/WIMP: Add new settings window to control all RetroArch settings.
  * MENU/RGUI: Improve playlist titles.
  * MENU/RGUI: Add option to hide associated cores in playlists.
  * MENU/RGUI: Add internal upscaling option.
  * MENU/RGUI: Add subsystem support.
  * MENU/RGUI: Add menu sublabel support.
  * MENU/RGUI: Re-enable "Load Core" option when content is loaded.
  * MENU/RGUI: Add optional "Collections" entry to main menu.
  * MENU/RGUI: Add "Lock Menu Aspect Ratio" option.
  * MENU/RGUI: Add "full width" layout option.
  * MENU/RGUI: Ensure menu color theme is applied immediately.
  * MENU/RGUI: Fix "Lock Menu Aspect Ratio" option when using custom viewports.
  * MENU/RGUI: Add widescreen support.
  * MENU/RGUI: Allow text to be centred when selecting widescreen layouts.
  * MENU/RGUI: Add inline playlist thumbnail support.
  * MENU/RGUI: Add optional shadow effects.
  * MENU/RGUI: Performance optimizations.
  * MENU/RGUI: Add optional extended ASCII support.
  * MENU/RGUI: Add optional delay when loading thumbnails.
  * MENU/RGUI: Add on-screen keyboard.
  * MENU/RGUI: Battery notifications.
  * MENU/XMB: Prevent crashes when resizing to a tiny window.
  * MENU/XMB: XMB honors the 'show menu sublabels' setting
    now - was previously RGUI only
  * NETPLAY: Fix stall-out causing total disconnection with >2 players.
  * NETPLAY: Different (more intuitive?) default netplay share policy.
  * NETPLAY: Add hotkey option to toggle hosting on/off.
  * NETWORKING: Encode URLs to allow for spaces in directory names.
  * OSX: Prevent crash on exit.
  * OSX: Metal is now the default video driver for the RetroArch Metal build.
  * OSX: Enable CoreAudio v3 driver for Metal.
  * OSX/MACOS/IOS: Now uses the STB Unicode font driver.
  * PS2: CDFS support.
  * PS2: Implemented analog support for ps2 controllers.
  * PS2: Fix audio freeze after restarting core.
  * PS2: Fix issues with load state and the font driver.
  * PS2: File I/O now works for USB and network host.
  * PS2: Support cores with extra padding in their frame buffers.
  * SCANNER: New option 'Scan without core match'. When this is enabled,
    supported extensions by all installed cores are not checked, and instead
    it will add all content it finds to a playlist. This way, you can install
    the core you need later on after scanning. Not enabled by default.
  * SHADERS: Don't alphabetize shader presets.
  * SWITCH: Add rumble support.
  * SWITCH: Add USB keyboard support.
  * VITA: Add bluetooth mouse and keyboard support.
  * VULKAN: Fix color issues with RGBA8888 swapchains in readback (screenshots).
  * WII: Don't init overlay when RAM is beyond 72MB.
  * WII: Skip CRC calculation on content load, can improve load times of
    larger games by several seconds.
  * WINDOWS: Fall back to gl1 driver if accelerated GPU driver is unavailable.
  * WINDOWS: Allow winraw and xinput to work without dinput (needed for WinRT).
  * WINDOWS: Add MSVC2017 ARM desktop support.
  * UWP: Fix rewind by opting for slower codepath.
  * UWP: Fix relative path name issues when loading shaders.
  * UWP: Optimizations for VFS system.
- from version 1.7.6
  * ANDROID: Fix Xperia Play input binding.
  * CHEEVOS: Reset when hardcore mode is toggled.
  * CHEEVOS: Update the hashing methods to identify NES, SNES and Lynx games
    (more accurate and accepting headerless ROMs).
  * COMMON: Add new JSON playlist format.
  * COMMON: Fix playlist corruption when deleting items.
  * COMMON: Fix archive progress display calculation.
  * COMMON: Fix playlist entries appearing with previously used names.
  * COMMON: Fix screenshot filename with no core or content.
  * COMMON: Allow compiling without menu support.
  * CORE UPDATER: Allow sideloading cores from the menu.
  * CPU FILTERS: Add Normal2x filter.
  * CRT/LINUX: New Linux switching method partially implemented.
  * CRT/LINUX: Linux restore desktop resolution fixed.
  * CRT/LINUX: Monitor index switching and auto enumerate for
    output detection in Linux (still working on the windows method).
  * CRT/RASPBERRY PI: Initial support.
  * DATE: Add Date / Time style options.
  * DEBUGGING: Add an integrated crash handler for debug builds
    (see https://docs.libretro.com/tech/debugging)
  * DISCORD: Register the application name properly.
  * DISK CONTROL: Remember the last used folder / current active
    folder to make disk-swapping faster.
  * INPUT: Add new menu toggle (hold start button for 2 seconds)
  * INPUT: Fix arrow keys being incorrectly bound as numpad keys
  * INPUT/SDL: Flush the joypad events. Decreases cpu usage over
    time with the SDL joypad driver.
  * LOCALIZATION: Add Greek translation.
  * LOCALIZATION: Update German translation.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Simplified Chinese translation.
  * LOCALIZATION: Update Spanish translation.
  * MENU: New "ozone" menu driver.
  * MENU: Only show CRT SwitchRes if video display server is
    implemented (Windows/Linux for now)
  * MENU: User Interface -> Appearance -> 'Menu Font Green/Blue Color'
    settings now work properly.
  * MENU: Add option to enable in-menu sound effects.
  * MENU/D3D: Scissoring support (will be used for Ozone and menu widgets).
  * MENU/QT/WIMP: Allow building with MSVC2017.
  * MENU/QT/WIMP: Add detailed file browser table.
  * MENU/QT/WIMP: New grid view implementation that is faster
    and loads thumbnails on-demand.
  * MENU/QT/WIMP: Thumbnail drag and drop support.
  * MENU/RGUI: Overhaul custom theme interface + add wallpaper support.
  * MENU/RGUI: Thumbnail support and thumbnail downscaling.
  * MENU: Hide password values.
  * MENU/SOUNDS: Implement in-menu sound effects (not enabled by
    default for now, still experimental).
  * MIDI: Add a Linux ALSA driver for MIDI.
  * NETPLAY: Force fast-save-states when netplay is enabled.
  * NETPLAY: Allow quick joining subsystem lobbies.
  * OSX: Initial CoreAudio V3 audio driver (not yet used in release builds).
  * OSX: OpenGL 3.2 Core support for cores.
  * PS2: Initial PlayStation2 port.
  * PS4: Initial PlayStation4 port.
  * RECORDING: Implement recording options in the menu complete
    with quality profiles, streaming, and proper file naming
  * SCANNER: Fix GDI disc scanning.
  * SHADERS: Fix auto shader preset loading on D3D10, D3D11, D3D12
  * SUBSYSTEM: Allow more than 10 subsystems
  * SUBSYSTEM: Cores that use subsystem for complex scenarios can
    now load content without starting a regular content first
  * SUBSYSTEM: Remember the last used folder to make loading
    subsystem type content faster
  * SWITCH/LIBNX: Improve touch scaling calculation.
  * SWITCH: Proper button labels.
  * TVOS: Initial tvOS port.
  * VULKAN: Fix RGUI crashing at startup.
  * VULKAN/RGUI: Enable 'Menu Linear Filter' option.
  * VULKAN: Fix secondary screens in overlays not working.
  * WAYLAND: Implement idle-inhibit support (needed for screensaver suspend).
  * WAYLAND: Fix fullscreen toggle.
  * WIIU: Initial netplay peer-to-peer support. Network information working.
  * WINDOWS/WSA: Network Information info is blank until first network operation.
  * WINDOWS: Fix an ancient bug that caused wrong mappings for keyboard arrows.
  * WINDOWS: Remember window size and position if so desired.
  * WINDOWS: SSL/TLS connections now work properly.
  * WINDOWS: Fall back to GDI driver if no accelerated graphics driver is found.
  * UWP: Initial UWP port.
  * VFS: Update to version 3.
  * XBONE: Initial Xbox One port.
  * XMB/OZONE: Add more icons
  * XMB: Add Automatic Inverted theme
  * ???: Easter Egg
- Clean up changelog file
- Stop enabling libxml2 support which has been removed upstream
  * Drop libxml2 build dependecy
  * Strip --enable-libxml2 from configure options
* Mon Oct 29 2018 Ismail Dönmez <idonmez@suse.com>
- Cleanup with spec-cleaner
* Sun Oct 28 2018 sean@suspend.net
- update to version 1.7.5
  * CAMERA: Fix Video4Linux2 driver that broke years ago
  * CONFIG: Add 'Reset to defaults' setting in Configurations.
    This will reset your config file to defaults
  * CHEATS: Add support for Rumble when increasing or decreasing by the rumble value
  * CHEATS: Add cheat variables to allow for updating large portions of memory
  * CHEEVOS: Prevent loading states before achievements are fully loaded
  * CRT: New porches and interlaced bug fix
  * CRT: New functionality, ability to switch between 15KHz and 31KHz
  * COMMON: Support for "OEM-102" key (usually '\' on Euro keyboards)
  * DISCORD: Add 'Ask to Join' Feature
  * EMSCRIPTEN: Add stb_font support
  * INPUT: Add new menu toggle combos 'L3 + R' and 'L + R' (useful for Switch)
  * IOS: Use safe area to account for notch for iPhone X and adjust main view
  * LOCALIZATION: Update Portugese / Brazilian translation
  * LOCALIZATION: Update Japanese translation
  * LOCALIZATION: Update Polish translation
  * LOCALIZATION: Update Spanish translation
  * MENU: Add dropdown lists for many settings
  * MENU: Fix crash that could happen when changing cores on Android
  * MENU/QT/WIMP: Add option to rename playlists
  * MENU/QT/WIMP: Add option to filter extensions inside archives
    when adding to a playlist
  * MENU/QT/WIMP: Rename playlist entries with 2 single clicks
  * MENU/QT/WIMP: Fix shader parameter checkboxes not working
  * METAL: Add screenshot support
  * NETPLAY: Save lobby details received back from server after first announcement
  * OPENGL/GLX: Implement Adaptive VSync - GLX_EXT_swap_control_tear
  * OPENGL/WGL: Implement Adaptive VSync - WGL_EXT_swap_control_tear
  * RUNAHEAD: Fix performance degradation that could happen over
    time. Fixed input IDs outside of range 0-35
  * SWITCH: Add stb_font support
  * SWITCH: Add Retro Achievements support
  * SWITCH: Add networking support
  * Add touchscreen support
  * Add OpenGL support
  * SWITCH: Merging of RetroNX Nintendo Switch port, based on libnx SDK
  * VULKAN: Fix race condition in threaded mailbox emulation
  * VULKAN: Maintenance fixes
  * WIIU: Fix menu lag when built with DevKitPro r32
* Tue Aug  7 2018 mardnh@gmx.de
- Build with supoort for the WIMP Qt GUI
* Sun Jun 24 2018 boris@steki.net
- update to version 1.7.3
  * AUDIO: Audio mixer supports FLAC/MP3 file types now!
  * COMMON: Fixed bug 'crashing in cores that don't range check
    retro_set_controller_type'. Some people were having crashes
    when device is set to RETRO_DEVICE_NONE and the cores don't
    check the number of ports, in VBAM's case it was overflowing
    and crashing. QuickNES was crashing too.
  * COMMON: Fixed buffer overflow in url encoding (affecting MSVC2010/2013).
  * COMMON: (QuickMenu) Added Configuration Override submenu.
  * HID: Merge new HID subsystem.
  * HID: Fix WaveBird support for the Wii U GCA.
  * HID/OSX: Fix regression with IODHIDManager - gamepads which are
    connected later would not be autoconfigured.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese translation.
  * MENU: New WIMP Qt GUI!
  * MENU: Audio mixer now works in the menu without any cores loaded.
    You have to enable the setting 'Enable menu audio' for this to work.
  * REMAPPING/OVERLAYS: Fix regression - overlays could no longer be remapped.
  * SCANNER: Add Wii Backup File WBFS support.
  * X11: CRT SwitchRes support for X11/Linux.
  * ANDROID/OPENSL: Prevent crashes when setting audio latency too low
    (buffer count can never be lower than 2 now).
  * CRT: Added CRT SwitchRes.
  * COMMON: Hide the 'Core delete' option if the 'Core updater' is also hidden.
  * COMMON: Add way to reset core association for playlist entry.
  * COMMON: Fix invalid long command line options causing infinite loop on Windows
  * COMMON: Add OSD statistics for video/audio/core.
  * COMMON: Added runahead system; allows you to drive down latency even further.
  * COMMON: Fix buggy behavior that could happen with ZIP file reading
    on some platforms as a result of not initializing struct.
  * CHEEVOS: Support Atari 2600, Virtual Boy, and Arcade (only Neo Geo,
    CPS-1, CPS-2 and CPS-3 and only with fbalpha core).
  * CHEEVOS: Add option to automatically take a screenshot when
    an achievement is triggered.
  * CHEEVOS: Fixed incompatibilities with Neo Geo Pocket achievement sets.
  * CHEEVOS: Store only login token, not password.
  * D3D10: Added D3D10 driver to release build. Has working shaders (Slang),
    overlay, and menu display driver support. Should be on par capabilities
    wise with D3D11 driver except for there being no hardware rendering right now.
  * D3D11: Experimental hardware renderer. Allows for libretro
    cores to use D3D11 for hardware rendering. First core to use this is PPSSPP.
  * D3D11: Increase backwards compatibility, shaders compile with Shader Model
    4.0 now, added support for more feature levels.
  * D3D10/D3D11/D3D12: Fix crashes with completely black
    or white thumbnail textures in XMB.
  * GUI: Support disabling window decorations on Windows and Linux.
  * LIBRETRO: Addition - Functions to enable and disable audio and
    video, and an environment function to query status of audio and video enables.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Polish translation.
  * MENU: Add Rewind/Latency/Overlay settings to Quick Menu, add options
    to show/hide them (User Interface -> Views -> Quick Menu)
  * MENU/RGUI: Only show Menu Linear Filter for RGUI and only show it
    for video drivers that implement it (D3D8/9/10/11/12/GL)
  * MENU/RGUI: Add User Interface -> Appearance options.
  * MENU/RGUI: D3D8/D3D9: Hookup Menu Linear Filter
  * MENU/XMB: Disable XMB shadow icons by default for PowerPC and ARM for performance reasons.
  * MENU/XMB: Left/right thumbnails are now automatically scaled according to layout.
  * MENU/XMB: Add Left Thumbnails (additional to the right).
  * MENU/XMB: Fixed left/right tab regression.
  * MENU/XMB: Fix scaling of tall images that were cut on bottom previously.
  * MENU/XMB: Menu scale factor setting now changes texts length, image scaling and margins.
  * MENU/XMB: Mouse cursor scales correctly now.
  * MENU/XMB: Add toggle to show/hide Playlist tabs.
  * MENU/XMB: Add menu layout - can switch between Desktop, Handheld and Auto.
  * MENU/XMB: Don't load menu pipeline shaders unless XMB is
    selected (D3D10/D3D11/D3D12/GL/Vulkan)
  * MENU/VIDEO: Only show black frame insertion for the video drivers/context
    drivers that support it (so far this includes - D3D8/D3D9, OpenGL, Vulkan)
  * MENU/VIDEO: Only show max swapchain images if supported by video driver and/or context driver
    (so far this includes - DRM EGL context driver, VideoCore EGL context driver, Vulkan)
  * MENU/MaterialUI: Automatic DPI Scaling should be much improved now,
    now scales as expected at 1440p and 4K resolutions.
  * MENU/MaterialUI: Fix wrong calculation of an entry height
    causing long playlists to end up outside of screen range.
    This also could cause crashes on low DPI screens.
  * IOS: Fixed crash when opening downloaded roms from Safari or using the "Open in.." functionality.
    Added the compiler flag to support keyboard remapping to controls.
  * IOS: Fixed buffer overlap that caused a crash while trying to download GLSL shaders from the buildbot.
  * PS3: fix URLS
  * REMAPS: Mapping keyboard keys from more than one gamepad (works with dosbox)
  * REMAPS: Mapping more than one button to the same action
  * REMAPS: Unmapping buttons
  * REMAPS: Unmapping analogs
  * REMAPS: Mapping a button to trigger an analog response (tested with mupen, can
    run on SM64 with the d-pad now, triggers a full analog tilt)
  * REMAPS: Mapping an analog to another analog (having more than one
    analog mapped to the same output causes issues)
  * REMAPS: Mapping an analog to produce a button response
  * SCANNER: Should be able to scan dual-layer Wii disc images now,
    filestream code now supports files larger than 4GB.
  * SHADERS/SLANG: Slang shaders should work again on Android version
    and MSVC versions (basically all the Griffin-based versions).
  * SHADERS: If GL context is GLES2/3/Core context, Cg shaders are unavailable.
    Applies to shader list too.
  * SHADERS: Hide cg/glsl shaders from being able to be selected if
    D3D8/9/10/11/Vulkan video drivers are selected.
  * SHADERS: Hide slang shaders from being able to be selected if
    D3D8/9/OpenGL video drivers are selected.
  * SHADERS: Prevent crashes from occurring if we have the GL video driver
    in use and we try to skip to a slang shader through next/previous hotkeys
  * SHADERS: Fix shader parameter increase / decrease functions
  * SUBSYSTEM: handle savestates properly (cart1 + cart2.state0)
  * VULKAN/X11: Fix X11 Vulkan bug from Wayland driver.
  * VULKAN: Fix multi-line text spacing in menus with Vulkan driver.
  * WINDOWS XP: Add Cheevos support.
  * WINDOWS/MSVC 2003/2005/2010/2013/2015/2017: Add Cheevos support.
  * VITA: Bugfix for 'PS Vita takes many time to start to accept input' issue.
  * X11: Allow compositor disabling on X11 fullscreen through _NET_WM_BYPASS_COMPOSITOR
  * X11: Prioritize NET_WM_STATE_FULLSCREEN in true fullscreen mode
  * WIIU: Fix OOB read/write in keyboard driver.
* Mon Mar 26 2018 igarcia@suse.com
- Updated to version 1.7.1
  – 3DS: Now correctly reports amount of CPU cores.
  * 3DS: Frontend rating is now correctly implemented for both New 3DS/2DS and Old 3DS/2DS.
  * 3DS: Initial networking support, HTTP requests won’t work yet.
  * 3DS: Now reports memory and battery state.
  * AUDIO: Added ‘Audio Resampler Quality’ setting to Audio Settings. Setting
    this higher will increase sound quality at the expense of sound latency
    and/or performance. Setting this value lower will improve sound latency/
    performance at the expense of sound quality. Only has an effect if the
    Sinc resampler is used, and you have to restart the game for changes to take effect.
  * CHEEVOS: Fix unofficial achievements not being loaded.
  * CHEEVOS: Show savestate menu entries when no achievements are
    found even if hardcore mode is enabled.
  * CHEEVOS: Support Neo Geo Pocket.
  * COMMON: Bugfix for issue related to ‘Windows mouse pointer visible
    when running MESS or MAME cores’.
  * COMMON: Fix bug ‘Last item in a Playlist is ignored’.
  * COMMON: New LED API. Driver implemented for Raspberry Pi, proof of
    concept implemented for core MAME 2003.
  * COMMON: Add quick menu option to watch shader files for changes and
    recompile them automatically (Linux only for now).
  * D3D8: Direct3D 8 can now work on systems that have Direct3D 8 installed.
  * D3D9: Add menu support for MaterialUI/XMB.
  * D3D10: Initial video driver implementation.
  * D3D11: Initial video driver implementation.
  * D3D11: SPIRV-Cross/slang shader support for D3D11.
  * D3D12: Initial video driver implementation.
  * DINPUT: don’t reinitialize input driver on network events /
    media insertion / network drive connection
  * INPUT: show friendly names when available under input binds and system information
  * INPUT: show the config name when available under system information
  * GUI: Allow changing menu font color.
  * GUI: Menu visibility options for RGUI and MaterialUI.
  * GUI/MaterialUI: Works now with D3D8, D3D9 Cg, D3D11 and D3D12 drivers.
  * GUI/XMB: Add Monochrome Inverted icon theme.
  * GUI/XMB: Allow changing menu scale to 200%%.
  * GUI/XMB: Works now with D3D8, D3D9 Cg, D3D11 and D3D12 drivers.
    Menu shader effects currently don’t work on D3D8/D3D9 Cg.
  * HAIKU: Restored port.
  * KEYMAPPER: prevent a condition that caused input_menu_toggle to stop
    working when a RETRO_DEVICE_KEYBOARD type device is enabled
  * GL: ignore hard gpu sync when fast-forwarding
  * IOS10/11: Handle hardware keyboards and iCade controllers
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Spanish translation.
  * NETPLAY: Add menu option to select different MITM (relay) server locations.
  * OSX: Modify HID buttons detection algorithm.
  * QB: Added –datarootdir.
  * QB: Added –bindir and –mandir and deprecated –with-bin_dir and –with-man_dir.
  * QB: Added –docdir.
  * SHADERS: Allow saving of shader presets based on the parent directory
    (Saving one for */foo/bar/mario.sfc* would result in *shaders/presets/corename/bar.ext*).
    We decided it’s safer to still isolate the presets to a single core
    because different cores may treat video output differently.
  * SHADERS: Don’t save the path to the current preset to the main config.
    This was causing weird behavior, instead it will try to load *currentconfig.ext*
    and it will save a preset with that name when select *apply shader preset*.
    The resulting shader will restore properly after restarting and even
    after core/parent/game specific presets are loaded
  * SOLARIS: Initial port.
  * SWITCH: Initial Nintendo Switch port, based on libtransistor SDK.
  * PS3: Enable Cheevos.
  * PSP: Enable threading support through pthreads.
  * SHADERS: SPIRV-Cross/slang shader support for D3D11.
  * SHIELD ATV: Allow the remote / gamepad takeover hack to work with the 2017 gamepad
  * SUBSYSTEM: Subsystem saves now respect the save directory
  * SUBSYSTEM: You can now load subsystem games from the menu
    (see https://github.com/libretro/RetroArch/pull/6282 for caveats)
  * VULKAN: Fix swapchain recreation bug on Nvidia GPUs with Windows 10
    (resolved in Windows Nvidia driver version 390.77).
  * WINDOWS: Improved Unicode support (for cores/directory creation and 7zip archives).
  * WINDOWS: Show progress meter on taskbar for downloads (Windows 7 and up).
  * WINDOWS: WS_EX_LAYERED drastically decreases performance, so only
    set it when needed (transparency in windowed mode).
  * WIIU: Overlay support.
  * WIIU: Transparency support in menu + overlays.
  * WIIU: Increased stability during core switching.
  * WIIU: Shader support.
  * WIIU: Menu shader effects added (shaders).
  * WIIU: Add missing time/clock support. (also fixes RTC [Real Time Clock] in Gambatte)
  * XBOX OG: Restored port.
* Fri Dec 29 2017 igarcia@suse.com
- Updated to version 1.7.0
  * CHEEVOS: Add badges for achievements, shows thumbnail images of achievements.
  * CHEEVOS: Leaderboard support.
  * CHEEVOS: Only disable savestates on hardcore mode if achievements are not available.
  * COMMANDLINE: Fix fullscreen toggle switch.
  * COMMON: Add 'Automatically Load Content To Playlist' feature, enabled by default.
  * COMMON: Fix slowmotion ratio always being reset back to 1.
  * COMMON: Optimized NBIO implementations now for Apple, Windows, and Linux.
    Uses mmap for Linux/Windows/BSD if/when available. File I/O should now
    be much faster for loading images inside the menu.
  * COMMON: Native Blissbox support now for latest firmware as of writing (2.0).
    Implementation through libusb and/or native Windows HID.
  * COMMON: New lightgun API.
  * COMMON: New VFS (Virtual File System) API.
  * COMMON: Fixed some playlist bugs.
  * COMMON: New snow shader.
  * COMMON: Fix Quick Menu title, no longer shows 'Select File'.
  * COMMON: Fix loading cores that require no content one after another.
  * COMMON: Map Delete key to Y button for non-unified menu keyboard controls.
  * COMMON: Fix for relative paths being normalised and generating a duplicate history entry.
  * EMSCRIPTEN: Fix references to browserfs.
  * FREEBSD: Support libusb HID input driver.
  * HAIKU: Buildfix.
  * INPUT: Map clear button to DEL key.
  * LINUX/X11: Add RetroArch logo to window title bar.
  * LINUX/X11: Input driver now supports new lightgun code.
  * LINUX/X11: Support window transparency (requires a compositing window manager).
  * LOBBIES: Fix for crash on join netplay rooms via touch / glui.
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Polish translation.
  * LOCALIZATION: Update Russian translation.
  * MENU: Snowflake menu shader effect.
  * OSX/PPC: Fix the GL2 renderchain, had to use EXT
    versions of framebuffer/renderbuffer functions.
  * PS3: HTTP requests / downloads should now work.
  * PS3: Core Updater now works.
  * PS3: Improved font rendering, enable STB Unicode font renderer.
  * PSP: Make it work with Vita's Adrenaline.
  * PSP: Fix audio sync.
  * PSP: Fix content loading, port should be functional again.
  * PSP: Use 64MB when available.
  * SCANNER: Fix crash from Windows-incompatible format string.
  * VITA: Improve packaging, installation times.
  * WIIU: Disabled the controller patcher for now since it was
    the source of many stability issues.
  * VULKAN: Various stability fixes for WSI.
  * WINDOWS: Add MSVC 2017 solution.
  * WINDOWS: Get rid of the empty console window in MSVC 2010 builds.
  * WINDOWS: Raw input driver now supports new lightgun code.
  * WINDOWS: Use configured OSD/text message color on GDI driver.
  * WINDOWS/XINPUT: Populate XInput VID/PID from DInput so
    autoconfig doesn't rely solely on joypad names
  * WINDOWS/XINPUT: Fix crash that occurs in some situations with
    Steam running and a Steam Controller plugged in.
  * WINDOWS: Improve version reporting under System Information.
  * WINDOWS: Support window transparency.
  * WINDOWS: Correct usage of GetWindowPlacement per MS docs,
    fixes game window position on Win95/98.
  * WINDOWS: Added Visual Studio 2017 support.
* Wed Dec 13 2017 igarcia@suse.com
- Updated to version 1.6.9
  * COMMON: Small memory leak.
  * NETPLAY: Fix network command only working once.
- Changes from 1.6.8:
  * Audio: Fix the Audio DSP picker
  * CHEEVOS: Add support for RetroAchievements Leaderboards.
  * GUI: (MaterialUI) Skip querying and drawing items that are not
    visible; Cache content height and bbox calculation.
  * GUI: (MaterialUI) Fix entry box highlight calculation.
  * GUI: (XMB) Skip drawing the fading list when it is already transparent. Optimization.
  * GUI: (XMB) Comment out visible item calculation in xmb_draw_items().
  * GUI: (RGUI) Prevent crashes when using a non-English language reliant on UTF8.
  * GUI: Add menu option for OSD background color.
  * GUI: Add menu option for OSD text color.
  * GUI: Add menu option to remove frame count from OSD.
  * GUI: Allow wraparound of int/float settings when pressing the left key
  * INPUT/LIBRETRO: Add support for more mouse buttons (buttons 4/5)
  * INPUT/LIBRETRO: Add support for analog buttons
  * INPUT: Always show the controls menu even if descriptors are not set
  * INPUT: Fix input descriptors not being set on cores that
    don't implement the controllers interface
  * INPUT: Apply descriptors only for the amount of cores the core supports
  * INPUT: Implement keyboard to gamepad input remapping
    (limited to one gamepad device for now)
  * INPUT: Fix absolute mouse move handling on the winraw driver
  * INPUT: Ignore keyboard input if window is not active on udev driver
  * INPUT: Sanitize the filenames of autoconfig profiles before saving
  * LOBBIES: Fix crash on navigating left / right from the lobby menu
  * LOCALIZATION: Update Dutch translation
  * LOCALIZATION: Update Italian translation.
  * LOCALIZATION: Update Japanese translation.
  * LOCALIZATION: Update Portuguese-Brazilian translation.
  * LOCALIZATION: Update Russian translation.
  * LINUX/ARMHF: Set buildbot updater URL to armhf location instead of blank string
  * LINUX/PI: Broadcom VC4: Add Videocore config option
  * LINUX/UDEV: Fix - RetroArch reads keyboard input when not focused with the udev input driver.
  * NETPLAY: Fix disconnection not fully deinitializing Netplay.
  * NETPLAY: Fix lan rooms when there is more than one room
  * NETPLAY: Fix lan rooms on systems where all addresses are treated as IPv6
  * COMMON: Fix clear/free loop conditionals in playlists.
  * WINDOWS/GDI: Fix flickering of text.
  * WINDOWS/GDI: Fix graphics corruption on Windows 98
  * WINDOWS/GDI: Allow compiling without DirectInput8 for NT support
  * WINDOWS/WGL: Try to use wglSwapLayerBuffers instead of
    SwapBuffers if possible (for more optimal performance).
  * WINDOWS: Fix menubar text corruption on Japanese locale systems
  * WINDOWS: Support Unicode file I/O (can now display CJK
    characters in file browser for example).
  * WINDOWS: Support Windows 95, NT3.51, NT4
  * WINDOWS: add Makefile.griffin targets for msvc6,2003,2005,2010,2012,2013
  * WII: Use custom, embedded libogc SDK.
  * WIIU: Initial touchscreen support for WiiU gamepad.
  * WIIU: Add Cheevos support.
  * SCANNER: Fix archive scanning.
  * SCANNER: Support CHD files.
  * SCANNER: Support Gamecube ISO scanning.
  * SCANNER: Use primary data track of disc images for CRC lookups rather than
    cue files. This is slower but finds matches more reliably, and is necessary
    for CHD files to work at all. Update your databases!
  * SCANNER: Fall back on looking inside archives when matching MAME/FBA content
    (most recent cores only). If you had difficulty with content being detected
    before, you may have better luck now. Update your databases and core info!
* Wed Aug 23 2017 glmarques.info@gmail.com
- Updated to version 1.6.7
  * NOTE: This is a bugfixed and spit-and-polish update. The initial release
    notes below are still from the 1.6.6 release.
  General changelog
  * SCANNER: Fix directory scanning.
  * SCANNER: Fix file scanning.
  * COMMON: Fix ‘Disk Image Append’ option.
  * FREEBSD: Compatibility fixes for Video4Linux2 camera driver.
  * GUI: (MaterialUI) Add disk image append icons.
  * GUI: (MaterialUI) Improve word wrapping when menu icons are enabled.
  * GUI: (MaterialUI) Add User Interface -> Appearance -> Menu Icons Enable.
    You can turn on/off the icons on the lefthand side of the menu entries.
  * GUI: Performance optimizations for XMB menu driver – only calculates visible items.
  * LOCALIZATION: Update Italian translation.
  Core updates since previous version (1.6.6)
  * Picodrive should hopefully work now again on Android after notaz‘ updates.
  * Beetle PSX’s OpenGL renderer should now work on various AMD GPUs thanks
    to rz5‘s efforts. There were previously some black screen issues on certain non-Polaris AMD GPUs.
  * Beetle PSX – Fixed bugs (geometry updates had max width and height unset, other ones) (by albertofustinoni).
  * Beetle Saturn – Unloading game leaves core unusable fix (by albertofustinoni).
  * Beetle Supergrafx – add turbo on/off for 2-button controller mode (by retrowertz).
  * Prosystem – NTSC Color Palette updates and DB updates (by underball).
* Fri Aug 11 2017 glmarques.info@gmail.com
- Updated to version 1.6.4
  General changelog
  * ANDROID: Fire Stick & Fire TV remote overrides gamepad port 0
    on button press and viceversa like SHIELD devices
  * ANDROID: Provide default save / system / state / screenshot locations
  * AUDIO: Audio mixer supports MOD/S3M/XM file types now!
  * INPUT: input swap override flag (for remotes) is cleared correctly
  * INPUT: allow specifying libretro device in remap files
  * INPUT: allow specifying analog dpad mode in remap files
  * INPUT: allow saving libretro device to remap files
  * INPUT: allow saving analog dpad mode to remap files
  * INPUT: allow removing core and game remap files from the menu
  * COMMON: Cores can now request to set a ‘shared context’. You no
    longer need to explicitly enable ‘Shared Hardware Context’
    for Citra/OpenLara/Dolphin.
  * COMMON: Add ‘Delete Core’ option to Core Information menu.
  * COMMON: Allow Max Timing Skew to be set to 0.
  * COMMON: Change the “content dir” behavior so it works on either a
    flag or an empty directory setting, now platform drivers can provide
    defaults for save / system / state / screenshot dirs and still allow
    the content dir functionality, these settings are under settings /
    saving and flagged as advanced
  * GUI: You can turn on/off ‘Horizontal Animation’ now for the XMB menu.
    Turning animations off can result in a performance boost.
  * GUI: Fix sublabel word-wrapping in XMB where multi-byte languages were cut off too soon
  * LOCALIZATION: Update Dutch translation
  * LOCALIZATION: Update Traditional Chinese translation
  * LOCALIZATION: Update Italian translation
  * LOCALIZATION: Update Russian translation
  * WINDOWS: Provide default save / system / state / screenshot locations
  * LOBBIES: Show what country the host is in
  * MENU: Enable OSD text rendering for gdi and libcaca drivers
  * WINDOWS 98/ME/2K: Set default directory for MSVC 2005 RetroArch version.
  * WII: Better V-Sync handling, backported from SuperrSonic.
  * WIIU: Exception handler rewritten.
* Thu Jul  6 2017 igarcia@suse.com
- Add version 1.6.1
